import java.io.File;
import java.util.Scanner;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileNameExtensionFilter;

/**
 * A class with methods for parsing text files of Sudoku puzzles.
 * 
 * @author Joel (AND YOUR NAME HERE IF MODIFIED)
 */
public class SudokuFileParser
{
	/**
	 * Reads a single sudoku puzzle from a file.
	 * @param filename The path to the file to load. If null, then this the user is prompted for a file with a JFileChooser
	 * @return A 2d-array of ints representing the puzzle.
	 */
	public static int[][] loadSinglePuzzle(String filename)
	{
		int[][] game = new int[9][9]; //only works on 9x9 puzzles atm

		File f = null; //the file we will read
		if(filename != null) //if given a filename, load that
			f = new File(filename);
		else //otherwise, pick a file
		{
			JFileChooser chooser = new JFileChooser();
			chooser.setFileFilter(new FileNameExtensionFilter("Text files", "txt")); //for choosing txt files
			int returnVal = chooser.showOpenDialog(chooser);
			if(returnVal == JFileChooser.APPROVE_OPTION) //if they picked something
				f = chooser.getSelectedFile();
		}

		if(f != null) //make sure we have picked something
		{
			try {
				Scanner sc = new Scanner(f); //parse it with Scanner
				sc.nextLine(); //get rid of the header line!
				int row = 0;
				while(sc.hasNextLine()) //read each line
				{
					String[] numAsString = sc.nextLine().split(","); //using built-in split to process each line
					for(int col = 0; col < numAsString.length; col++)
					{
						game[row][col] = Integer.parseInt(numAsString[col]); //turn String into number and store
					}
					row++;
				}
				sc.close(); //close scanner when we're done, for cleanup
			}
			catch(Exception e) {
				System.out.println("Error loading from file: "+e);
				e.printStackTrace();
			}
		}		

		return game; //return the puzzle
	}

}
